.. QPtomographer documentation master file, created by sphinx-quickstart on Mon
   Aug 21 12:25:18 2017.  You can adapt this file completely to your liking, but
   it should at least contain the root `toctree` directive.

Reliable process tomography with QPtomographer
==============================================

This Python package implements practical and reliable diamond norm estimation to
any reference channel, given any measurements taken in a quantum process
tomography procedure, using the method described in |paper_arxiv_ref|.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   figures_of_merit
   api_conventions
   QPtomographer


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
